% Script file to generate the SDE section figure for HSCC 2005 submission
%   using viscousIntegrator routine.
%
% This figure compares the terminal cost for the viscous double integrator
%   with and without stochastic viscosity.
%
% Most problem parameters (tmax, grid, IC) can only be modified in
%   viscousIntegrator.

% Copyright 2004 Ian M. Mitchell (mitchell@cs.ubc.ca).
% This software is used, copied and distributed under the licensing 
%   agreement contained in the file LICENSE in the top directory of 
%   the distribution.
%
% Ian Mitchell, 9/28/04

% Parameters.
k1always = 0.5;
k2deterministic = 1e-6;
k2stochastic = 1;

% Get results without stochastic viscosity.
%   Use high accuracy, since there is no stochastic diffusion.
[ dataDeterministic, g, data0 ] = ...
  viscousIntegrator(k1always, k2deterministic, 'high');

% Get results with stochastic viscosity.
%   Use only medium accuracy, since stochastic diffusion damps out
%   sharp features anyway.
[ dataStochastic, g, data0 ] = ...
  viscousIntegrator(k1always, k2stochastic, 'medium');


% Plot everything together on one figure.
figure;
[ gar, hD ] = contour(g.xs{1}, g.xs{2}, dataDeterministic, [ 0.1 0.9 ], '--');
hold on
[ gar, hS ] = contour(g.xs{1}, g.xs{2}, dataStochastic, [ 0.1 0.9 ], '-');
[ gar, h0 ] = contour(g.xs{1}, g.xs{2}, data0, [ 0.1 0.9 ], ':');
axis equal;
axis([ -1 +1 -1 +1 ]);
xlabel('position');  ylabel('velocity');
set([ hD; hS; h0 ], 'LineWidth', 3);
